@@ -17,7 +17,22 @@ urls = {
     'spotify': "https://spotify.com",
     'udemy': "https://www.udemy.com",
     'linuxmint': "https://linuxmint.com/",
-    'dogemeet': "https://doge-meet-demo.up.railway.app/"
+    'dogemeet': "https://doge-meet-demo.up.railway.app/",
+    'dino-game':"chrome://dino",
+    'google':"https://google.com",
+    'duckduckgo': "https://duckduckgo.com",
+    'titanurl':"https://titul.herokuapp.com/",
+    'lolacli':"http://lolacli.herokuapp.com",
+    'whatsapp-web':"https://web.whatsapp.com/",
+    'netflix':"https://netflix.com/",
+    'prime':"https://primevideo.com/",
+    'disney+':"https://disneyplus.com/",
+    'amazon':"https://amazon.com/",
+    'pdfdrive':"https://pdfdrive.com/",
+    'duolingo':"https://www.duolingo.com/",
+    'wikipedia':"https://wikipedia.org/",
+    'facebook':"https://facebook.com/",
+    'instagram':"https://instagram.com/"
 }
 
 class WebEnginePage(QWebEnginePage):
@@ -40,7 +55,7 @@ def _downloadRequested(item): # QWebEngineDownloadItem
 application= QApplication(sys.argv)
 
 @click.group()
-@click.version_option('0.2.8')
+@click.version_option('0.2.9')
 def main():
     """RSB - webpages in GUI VIEW"""
     pass
